@@ -9,8 +9,9 @@ import pytest
 from astropy.utils.data import get_pkg_data_filename
 from astropy.nddata import CCDData
 
-from ..combiner import Combiner, combine, _calculate_step_sizes
-from .pytest_fixtures import ccd_data as ccd_data_func
+from ccdproc.combiner import Combiner, combine, _calculate_step_sizes
+from ccdproc.image_collection import ImageFileCollection
+from ccdproc.tests.pytest_fixtures import ccd_data as ccd_data_func
 
 
 # test that the Combiner raises error if empty
@@ -322,7 +323,7 @@ def test_combiner_mask_sum():
 
 # test combiner convenience function reads fits file and combine as expected
 def test_combine_average_fitsimages():
-    fitsfile = get_pkg_data_filename('data/a8280271.fits')
+    fitsfile = get_pkg_data_filename('data/a8280271.fits', package='ccdproc.tests')
     ccd = CCDData.read(fitsfile, unit=u.adu)
     ccd_list = [ccd] * 3
     c = Combiner(ccd_list)
@@ -373,6 +374,43 @@ def test_combiner_result_dtype():
     np.testing.assert_array_almost_equal(res.data, ref)
 
 
+def test_combiner_image_file_collection_input(tmp_path):
+    # Regression check for #754
+    ccd = ccd_data_func()
+    for i in range(3):
+        ccd.write(tmp_path / f'ccd-{i}.fits')
+
+    ifc = ImageFileCollection(tmp_path)
+    comb = Combiner(ifc.ccds())
+    np.testing.assert_array_almost_equal(ccd.data,
+                                         comb.average_combine().data)
+
+
+def test_combine_image_file_collection_input(tmp_path):
+    # Another regression check for #754 but this time with the
+    # combine function instead of Combiner
+    ccd = ccd_data_func()
+    for i in range(3):
+        ccd.write(tmp_path / f'ccd-{i}.fits')
+
+    ifc = ImageFileCollection(tmp_path)
+
+    comb_files = combine(ifc.files_filtered(include_path=True),
+                         method='average')
+
+    comb_ccds = combine(ifc.ccds(), method='average')
+
+    np.testing.assert_array_almost_equal(ccd.data,
+                                         comb_files.data)
+    np.testing.assert_array_almost_equal(ccd.data,
+                                         comb_ccds.data)
+
+    with pytest.raises(FileNotFoundError):
+        # This should fail because the test is not running in the
+        # folder where the images are.
+        _ = combine(ifc.files_filtered())
+
+
 # test combiner convenience function works with list of ccddata objects
 def test_combine_average_ccddata():
     fitsfile = get_pkg_data_filename('data/a8280271.fits')
@@ -696,3 +734,13 @@ def test_ystep_calculation(num_chunks, expected):
 
     xstep, ystep = _calculate_step_sizes(2000, 2000, num_chunks)
     assert xstep == expected[0] and ystep == expected[1]
+
+def test_combiner_gen():
+    ccd_data = ccd_data_func()
+    def create_gen():
+        yield ccd_data
+        yield ccd_data
+        yield ccd_data
+    c = Combiner(create_gen())
+    assert c.data_arr.shape == (3, 100, 100)
+    assert c.data_arr.mask.shape == (3, 100, 100)
