@@ -2,7 +2,7 @@
 
 import os
 from shutil import rmtree
-from tempfile import mkdtemp, TemporaryDirectory
+from tempfile import mkdtemp, TemporaryDirectory, NamedTemporaryFile
 from glob import iglob
 from pathlib import Path
 import logging
@@ -16,10 +16,11 @@ from astropy.tests.helper import catch_warnings
 from astropy.utils.data import get_pkg_data_filename
 from astropy.utils import minversion
 from astropy.utils.exceptions import AstropyUserWarning
+from astropy.io.fits.verify import VerifyWarning
 
 from astropy.nddata import CCDData
 
-from ..image_collection import ImageFileCollection
+from ccdproc.image_collection import ImageFileCollection
 
 _filters = []
 _original_dir = ''
@@ -35,11 +36,11 @@ def test_fits_summary(triage_setup):
     assert len(summary['file']) == triage_setup.n_test['files']
     for keyword in keywords:
         assert len(summary[keyword]) == triage_setup.n_test['files']
-    # explicit conversion to array is needed to avoid astropy Table bug in
+    # Explicit conversion to array is needed to avoid astropy Table bug in
     # 0.2.4
     no_filter_no_object_row = np.array(summary['file'] ==
                                        'no_filter_no_object_bias.fit')
-    # there should be no filter keyword in the bias file
+    # There should be no filter keyword in the bias file
     assert summary['filter'][no_filter_no_object_row].mask
 
 
@@ -208,7 +209,7 @@ class TestImageFileCollection:
         n_hdus = 0
         for hdu in collection.hdus():
             assert isinstance(hdu, fits.PrimaryHDU)
-            data = hdu.data  # must access the data to force scaling
+            data = hdu.data  # Must access the data to force scaling
             # pre-astropy 1.1 unsigned data was changed to float32 and BZERO
             # removed. In 1.1 and later, BZERO stays but the data type is
             # unsigned int.
@@ -384,11 +385,11 @@ class TestImageFileCollection:
                                                               triage_setup):
         collection = ImageFileCollection(location=triage_setup.test_dir,
                                          keywords=['imagetyp'])
-        # ensure all files are originally unmasked
+        # Ensure all files are originally unmasked
         assert not collection.summary['file'].mask.any()
-        # generate list that will match NO files
+        # Generate list that will match NO files
         collection.files_filtered(imagetyp='foisajfoisaj')
-        # if the code works, this should have no permanent effect
+        # If the code works, this should have no permanent effect
         assert not collection.summary['file'].mask.any()
 
     @pytest.mark.parametrize("new_keywords,collection_keys", [
@@ -403,10 +404,10 @@ class TestImageFileCollection:
         tbl_new = collection.summary
 
         if set(new_keywords).issubset(collection_keys):
-            # should just delete columns without rebuilding table
+            # Should just delete columns without rebuilding table
             assert(tbl_orig is tbl_new)
         else:
-            # we need new keywords so must rebuild
+            # We need new keywords so must rebuild
             assert(tbl_orig is not tbl_new)
 
         for key in new_keywords:
@@ -439,7 +440,7 @@ class TestImageFileCollection:
         assert str(w[0].message) == "no FITS files in the collection."
         assert collection.summary is None
         for hdr in collection.headers():
-            # this statement should not be reached if there are no FITS files
+            # This statement should not be reached if there are no FITS files
             assert 0
 
     def test_dir_with_no_keys(self, tmpdir):
@@ -448,7 +449,7 @@ class TestImageFileCollection:
         bad_dir = tmpdir.mkdtemp()
         not_really_fits = bad_dir.join('not_fits.fit')
         not_really_fits.dump('I am not really a FITS file')
-        # make sure an error will be generated if the FITS file is read
+        # Make sure an error will be generated if the FITS file is read
         with pytest.raises(IOError):
             fits.getheader(not_really_fits.strpath)
 
@@ -484,7 +485,7 @@ class TestImageFileCollection:
                                  keywords=keywords_in)
         for key in set(keywords_in):
             assert (key in ic.keywords)
-        # one keyword gets added: file
+        # One keyword gets added: file
         assert len(ic.keywords) < len(keywords_in) + 1
 
     def test_keyword_includes_file(self, triage_setup):
@@ -520,7 +521,7 @@ class TestImageFileCollection:
     def test_collection_when_one_file_not_fits(self, triage_setup):
         not_fits = 'foo.fit'
         path_bad = os.path.join(triage_setup.test_dir, not_fits)
-        # create an empty file...
+        # Create an empty file...
         with open(path_bad, 'w'):
             pass
         ic = ImageFileCollection(triage_setup.test_dir, keywords=['imagetyp'])
@@ -572,14 +573,13 @@ class TestImageFileCollection:
 
     def test_no_fits_files_in_collection(self):
         with catch_warnings(AstropyUserWarning) as warning_lines:
-            # FIXME: What exactly does this assert?
-            assert "no fits files in the collection."
+            assert "no FITS files in the collection."
 
     def test_initialization_with_no_keywords(self, triage_setup):
         # This test is primarily historical -- the old default for
         # keywords was an empty list (it is now the wildcard '*').
         ic = ImageFileCollection(location=triage_setup.test_dir, keywords=[])
-        # iteration below failed before bugfix...
+        # Iteration below failed before bugfix...
         execs = 0
         for h in ic.headers():
             execs += 1
@@ -634,6 +634,8 @@ class TestImageFileCollection:
         ic = ImageFileCollection(triage_setup.test_dir, keywords='*')
         assert 'col0' not in ic.summary.colnames
 
+    @pytest.mark.skipif("os.environ.get('APPVEYOR') or os.sys.platform == 'win32'",
+                        reason="fails on Windows because of file permissions.")
     def test_header_with_long_history_roundtrips_to_disk(self, triage_setup):
         # I tried combing several history comments into one table entry with
         # '\n'.join(history), which resulted in a table that couldn't
@@ -650,8 +652,10 @@ class TestImageFileCollection:
         path_history = os.path.join(triage_setup.test_dir, 'long_history.fit')
         long_history.writeto(path_history)
         ic = ImageFileCollection(triage_setup.test_dir, keywords='*')
-        ic.summary.write('test_table.txt', format='ascii.csv')
-        table_disk = Table.read('test_table.txt', format='ascii.csv')
+        with NamedTemporaryFile() as test_table:
+            ic.summary.write(test_table.name, format='ascii.csv',
+                             overwrite=True)
+            table_disk = Table.read(test_table.name, format='ascii.csv')
         assert len(table_disk) == len(ic.summary)
 
     @pytest.mark.skipif("os.environ.get('APPVEYOR') or os.sys.platform == 'win32'",
@@ -768,7 +772,7 @@ class TestImageFileCollection:
 
     def test_glob_matching(self, triage_setup):
         # We'll create two files with strange names to test glob
-        #   includes / excludes
+        # includes / excludes
         one = fits.PrimaryHDU()
         one.data = np.zeros((5, 5))
         one.header[''] = 'whatever'
@@ -783,7 +787,7 @@ class TestImageFileCollection:
                                    glob_exclude='*other*')
         assert len(coll.files) == 1
 
-        # the glob attributes are readonly, so setting them raises an Exception.
+        # The glob attributes are readonly, so setting them raises an Exception.
         with pytest.raises(AttributeError):
             coll.glob_exclude = '*stuff*'
         with pytest.raises(AttributeError):
@@ -973,18 +977,21 @@ class TestImageFileCollection:
             TESTVERI= '2017/02/13-16:51:38 / Test VerifyWarning
         """
 
-        testh = fits.Header.fromstring(bad_header)
-        print(testh)
-        testfits = fits.PrimaryHDU(data=np.ones((10, 10)), header=testh)
+        with catch_warnings(VerifyWarning) as warning_lines:
+            testh = fits.Header.fromstring(bad_header)
+            print(testh)
 
-        path = Path(triage_setup.test_dir)
-        bad_fits_name = 'test_warnA.fits'
-        testfits.writeto(path / bad_fits_name,
-                         output_verify='warn',
-                         overwrite=True)
+            testfits = fits.PrimaryHDU(data=np.ones((10, 10)), header=testh)
+
+            path = Path(triage_setup.test_dir)
+            bad_fits_name = 'test_warnA.fits'
+            testfits.writeto(path / bad_fits_name,
+                             output_verify='warn',
+                             overwrite=True)
+
+            ic = ImageFileCollection(location=str(path))
+            print(ic.summary.colnames)
 
-        ic = ImageFileCollection(location=str(path))
-        print(ic.summary.colnames)
         assert bad_fits_name in ic.files
 
         # Turns out this sample header is so messed up that TESTVERI does not
@@ -1008,7 +1015,9 @@ class TestImageFileCollection:
         # with no keys and no files returns None.
 
         # Make a dummy keyword that we then delete.
-        ic = ImageFileCollection(triage_setup.test_dir, keywords=['fafa'])
+        with catch_warnings(AstropyUserWarning) as warning_lines:
+            ic = ImageFileCollection(triage_setup.test_dir, keywords=['fafa'])
+        assert "no FITS files in the collection."
         ic.keywords = []
         assert set(ic.summary.colnames) == set(['file'])
 
@@ -1086,3 +1095,8 @@ class TestImageFileCollection:
         assert len(new_ic.summary) == triage_setup.n_test['light']
         for header in new_ic.headers():
             assert header['imagetyp'].lower() == 'light'
+
+    def test_filtered_collection_with_no_files(self, triage_setup):
+        ifc = ImageFileCollection(triage_setup.test_dir)
+
+        ifc_no_files = ifc.filter(object='really fake object')
